==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_EMAIL","E-mail");

define("_RE","Re");
define("_SUBJECT","Sujet");
define("_PRIVATEMESSAGES","Vos messages priv&eacute;s");
define("_CHECKALL","v&eacute;rifier tout");
define("_FROM","De");
define("_DATE","Date");
define("_DONTHAVEMESSAGES","Vous n'avez pas de message");
define("_NOTREAD","non lu");
define("_MSGSTATUS","Status du message");
define("_PRIVATEMESSAGE","Message priv&eacute;");
define("_INDEX","Index");
define("_SENT","Envoy&eacute;");
define("_PREVIOUSMESSAGE","Message pr&eacute;c&eacute;dent");
define("_NEXTMESSAGE","Message suivant");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","A propos de la messagerie");
define("_ALLREGCANPOST","Tous les utilisateurs enregistr&eacute;s peuvent poster des messages priv&eacute;s");
define("_TO","&agrave;");
define("_MESSAGEICON","Ic&ocirc;ne du message");
define("_MESSAGE","Message");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","a &eacute;crit");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","D&eacute;sactiver le HTML pour ce message");
define("_BBCODEDISSABLE","D&eacute;sactiver le <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> pour ce message");
define("_SMILEDISSABLE","D&eacute;sactiver les <a href=\"bb_smilies.php\" target=\"_blank\"><i>&eacute;moticons</i></a> pour ce message");
define("_CANCELREPLY","Annuler la r&eacute;ponse");
define("_CANCELSEND","Annuler l'envoi");
define("_CLEAR","Effacer");
define("_SUBMIT","Soumettre");
define("_USERNOTINDB","L'utilisateur s&eacute;lectionn&eacute; n'existe pas dans la base de donn&eacute;es.");
define("_CHECKNAMEANDTRY","V&eacute;rifiez le nom et essayez &agrave; nouveau.");
define("_MSGPOSTED","Votre message a &eacute;t&eacute; post&eacute;.");
define("_RETURNTOPMSG","Vous pouvez cliquer ici pour recharger vos messages priv&eacute;s.");
define("_MSGDELETED","Vos messages ont &eacute;t&eacute; effac&eacute;s.");
define("_BBGO","Aller");
define("_BBNEWPMSG","Nouveaux messages");
define("_BBNONEWPMSG","Aucun nouveaux messages");
define("_BBTOTALPMSG","Total de messages");
define("_BBEMPTYPMSG","Vous n'avez aucun messages");
define("_BBLOGIN","Connectez vous pour voir vos messages privs");
define("_BBPMSG","Message priv");
define("_BBINBOX","dans la box");
define("_BBSELECTFORUM","Choisir un Forum");
define("_BBNOFORUM","Plus de Forums");
define("_BBBANNED","Bannit");
define("_CLICKSMILEBUTTONS","Cliquez sur les Smilies pour les insrer dans votre message:");
define("_CLICKCODEBUTTONS","Cliquez sur les boutons suivants pour ajouter du BBCode dans votre message:");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Private_Messages/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_EMAIL","E-mail");

define("_RE","Re");
define("_SUBJECT","Sujet");
define("_PRIVATEMESSAGES","Vos messages priv&eacute;s");
define("_CHECKALL","v&eacute;rifier tout");
define("_FROM","De");
define("_DATE","Date");
define("_DONTHAVEMESSAGES","Vous n'avez pas de message");
define("_NOTREAD","non lu");
define("_MSGSTATUS","Status du message");
define("_PRIVATEMESSAGE","Message priv&eacute;");
define("_INDEX","Index");
define("_SENT","Envoy&eacute;");
define("_PREVIOUSMESSAGE","Message pr&eacute;c&eacute;dent");
define("_NEXTMESSAGE","Message suivant");
define("_PROFILE","Profil");
define("_ABOUTPOSTING","A propos de la messagerie");
define("_ALLREGCANPOST","Tous les utilisateurs enregistr&eacute;s peuvent poster des messages priv&eacute;s");
define("_TO","&agrave;");
define("_MESSAGEICON","Ic&ocirc;ne du message");
define("_MESSAGE","Message");
define("_HTML","HTML");
define("_PMON","On");
define("_PMOFF","Off");
define("_BBCODE","BBCode");
define("_WROTE","a &eacute;crit");
define("_OPTIONS","Options");
define("_HTMLDISSABLE","D&eacute;sactiver le HTML pour ce message");
define("_BBCODEDISSABLE","D&eacute;sactiver le <a href=\"bbcode_ref.php\" target=\"_blank\"><i>BBCode</i></a> pour ce message");
define("_SMILEDISSABLE","D&eacute;sactiver les <a href=\"bb_smilies.php\" target=\"_blank\"><i>&eacute;moticons</i></a> pour ce message");
define("_CANCELREPLY","Annuler la r&eacute;ponse");
define("_CANCELSEND","Annuler l'envoi");
define("_CLEAR","Effacer");
define("_SUBMIT","Soumettre");
define("_USERNOTINDB","L'utilisateur s&eacute;lectionn&eacute; n'existe pas dans la base de donn&eacute;es.");
define("_CHECKNAMEANDTRY","V&eacute;rifiez le nom et essayez &agrave; nouveau.");
define("_MSGPOSTED","Votre message a &eacute;t&eacute; post&eacute;.");
define("_RETURNTOPMSG","Vous pouvez cliquer ici pour recharger vos messages priv&eacute;s.");
define("_MSGDELETED","Vos messages ont &eacute;t&eacute; effac&eacute;s.");
define("_BBGO","Aller");
define("_BBNEWPMSG","Nouveaux messages");
define("_BBNONEWPMSG","Aucun nouveaux messages");
define("_BBTOTALPMSG","Total de messages");
define("_BBEMPTYPMSG","Vous n'avez aucun messages");
define("_BBLOGIN","Connectez vous pour voir vos messages privs");
define("_BBPMSG","Message priv");
define("_BBINBOX","dans la box");
define("_BBSELECTFORUM","Choisir un Forum");
define("_BBNOFORUM","Plus de Forums");
define("_BBBANNED","Bannit");
define("_CLICKSMILEBUTTONS","Cliquez sur les Smilies pour les insrer dans votre message:");
define("_CLICKCODEBUTTONS","Cliquez sur les boutons suivants pour ajouter du BBCode dans votre message:");


?>
